@@ -1,7 +1,7 @@
 use super::WriteItem;
 
 /// Prints writer items to a string.
-pub fn print_write_items<'a>(write_items: impl Iterator<Item = &'a WriteItem<'a>>, options: WriteItemsPrinterOptions) -> String {
+pub fn print_write_items<'a>(write_items: impl Iterator<Item = WriteItem<'a>>, options: WriteItemsPrinterOptions) -> String {
   WriteItemsPrinter::new(options).write_items_to_string(write_items)
 }
 
@@ -32,11 +32,11 @@ impl WriteItemsPrinter {
     }
   }
 
-  pub fn write_items_to_string<'a>(&self, write_items: impl Iterator<Item = &'a WriteItem<'a>>) -> String {
+  pub fn write_items_to_string<'a>(&self, write_items: impl Iterator<Item = WriteItem<'a>>) -> String {
     // todo: faster string manipulation? or is this as good as it gets?
     let mut final_string = String::new();
 
-    for item in write_items.into_iter() {
+    for item in write_items {
       self.write_to_string(&mut final_string, item);
     }
 
@@ -44,10 +44,10 @@ impl WriteItemsPrinter {
   }
 
   #[inline]
-  pub fn write_to_string(&self, final_string: &mut String, item: &WriteItem) {
+  pub fn write_to_string(&self, final_string: &mut String, item: WriteItem) {
     // todo: cache indent strings?
     match item {
-      WriteItem::Indent(times) => final_string.push_str(&self.indent_string.repeat(*times as usize)),
+      WriteItem::Indent(times) => final_string.push_str(&self.indent_string.repeat(times as usize)),
       WriteItem::NewLine => final_string.push_str(&self.new_line_text),
       WriteItem::Tab => final_string.push('\t'),
       WriteItem::Space => final_string.push(' '),
